@@ -10,8 +10,8 @@ from ..utils.learning_types import SELF_SUPERVISED
 from ..Optimizers.config import *
 
 class VAE(AutoEncoder):
-    def __init__(self) -> None:
-        super(VAE, self).__init__()
+    def __init__(self, device = None) -> None:
+        super(VAE, self).__init__(device=device)
 
     def forward(self, x):
         params = self.encoder(x)
@@ -43,8 +43,8 @@ class VAE(AutoEncoder):
             return self.decoder(z)
 
 class Beta_VAE(VAE):
-    def __init__(self, beta = 10) -> None:
-        super(Beta_VAE, self).__init__()
+    def __init__(self, beta = 10, device = None) -> None:
+        super(Beta_VAE, self).__init__(device=device)
 
         self.beta = beta
 
